using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Data.OleDb;

using Infragistics.Win;
using Infragistics.Win.UltraWinSchedule;
using Infragistics.Win.UltraWinEditors;
using Infragistics.Win.UltraWinToolbars;
using Microsoft.Win32;

namespace Infragistics.Win.UltraWinSchedule.Samples
{
	#region Outlook2003AppointmentDialog
	/// <summary>
	/// The AppointmentDialog class derives from System.Windows.Forms.Form; it emulates the
	/// Appointment dialog that ships with MS Outlook 2003.
	/// </summary>
	public class Outlook2003AppointmentDialog : System.Windows.Forms.Form
	{

        // added by Loo 13-03-2009 for owner key
        private string strOwnerKey;

		private Infragistics.Win.UltraWinToolbars.UltraToolbarsManager ultraToolbarsManager1;
		private System.Windows.Forms.Panel Outlook2003AppointmentDialog_Fill_Panel;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top;
		private Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom;
		private Infragistics.Win.UltraWinTabControl.UltraTabControl ultraTabControl1;
		private Infragistics.Win.UltraWinTabControl.UltraTabSharedControlsPage ultraTabSharedControlsPage1;
		private Infragistics.Win.UltraWinTabControl.UltraTabPageControl ultraTabPageControl1;
		private Infragistics.Win.UltraWinTabControl.UltraTabPageControl ultraTabPageControl2;
		private Infragistics.Win.Misc.UltraLabel lblSubject;
		private Infragistics.Win.Misc.UltraLabel lblLocation;
		private Infragistics.Win.UltraWinEditors.UltraTextEditor txtSubject;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboLocation;
		private Infragistics.Win.Misc.UltraLabel lblLabel;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboLabel;
		private Infragistics.Win.Misc.UltraLabel lblSeparator1;
		private Infragistics.Win.Misc.UltraLabel lblStartTime;
		private Infragistics.Win.Misc.UltraLabel lblEndTime;
		private Infragistics.Win.UltraWinSchedule.UltraCalendarCombo dtpStartTime;
		private Infragistics.Win.UltraWinSchedule.UltraCalendarCombo dtpEndTime;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboStartTime;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboEndTime;
		private Infragistics.Win.UltraWinEditors.UltraCheckEditor chkAllDayEvent;
		private Infragistics.Win.Misc.UltraLabel ultraLabel2;
		private Infragistics.Win.UltraWinEditors.UltraCheckEditor chkReminder;
		private Infragistics.Win.Misc.UltraLabel lblBarColor;
		private Infragistics.Win.UltraWinEditors.UltraColorPicker clrBarColor;
		private System.ComponentModel.IContainer components;
		private Infragistics.Win.UltraWinEditors.UltraTextEditor txtDescription;
		private Infragistics.Win.UltraWinEditors.UltraComboEditor cboReminder;
		private Infragistics.Win.Misc.UltraButton cmdReminder;
		private Infragistics.Win.Misc.UltraLabel lblStatus;

		#region Constants
		//	Appointment statuses
		private static readonly string APPOINTMENT_IN_THE_PAST = "This appointment occurs in the past.";
		private static readonly string APPOINTMENT_CONFLICTS = "Conflicts with another appointment on your Calendar.";

		//	Exception messages
		private static readonly string NULL_APPOINTMENT_EXCEPTION = "The dialog cannot be displayed for a null or disposed Appointment object";
		private static readonly string NULL_CALENDAR_INFO_EXCEPTION = "The dialog cannot be displayed for a null or disposed UltraCalendarInfo object";
		private static readonly string NON_ASSOCIATED_CALENDAR_INFO_EXCEPTION = "The specified appointment belongs to a different UltraCalendarInfo object than the specified calendarInfo; this is not supported.";

		//	Dialog messages
		private static readonly string INVALID_DATE_MESSAGE = "You must specify a valid date and/or time. Check your entries in this dialog box to make sure they represent a valid date and/or time.";
		private static readonly string DELETE_APPOINTMENT_CONFIRMATION = "This item has been changed. Are you sure you want to delete it?";

		//	Application-specific
		private static readonly string APP_TITLE = "Appointment Dialog";
		private static readonly string APP_REGISTRY_PATH = @"Software\Infragistics\Outlook2003AppointmentDialog";
		private static readonly int MAX_LOCATION_LIST_ITEMS = 5;

		#endregion Constants

		#region Private member variables
		
		private Appointment appointment = null;
		private Appointment oldAppointment = null;
		private UltraCalendarInfo calendarInfo = null;
		private System.Windows.Forms.ColumnHeader subject;
		private System.Windows.Forms.ColumnHeader location;
		private System.Windows.Forms.ColumnHeader label;
		private System.Windows.Forms.ColumnHeader startDate;
		private System.Windows.Forms.ColumnHeader endTime;
		private System.Windows.Forms.ColumnHeader endDate;
		private System.Windows.Forms.ColumnHeader startTime;
		private System.Windows.Forms.ColumnHeader allDayEvent;
		private System.Windows.Forms.ListView lvwScheduling;
        private UltraTextEditor txtRemarks;
        private Infragistics.Win.Misc.UltraLabel ultraLabel1;
		private bool isExistingAppointment = false;

		#endregion Private member variables

		#region Constructor
		/// <summary>
		/// Creates a new instance of the <see cref="Outlook2003AppointmentDialog"/> class.
		/// </summary>
		public Outlook2003AppointmentDialog()
		{
			InitializeComponent();

		}
		#endregion Constructor

		#region System.Windows.Control overrides

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if (components != null) 
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}
		
		#endregion System.Windows.Control overrides

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
            this.components = new System.ComponentModel.Container();
            Infragistics.Win.Appearance appearance1 = new Infragistics.Win.Appearance();
            System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(Outlook2003AppointmentDialog));
            Infragistics.Win.Appearance appearance2 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton dateButton1 = new Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton();
            Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton dateButton2 = new Infragistics.Win.UltraWinSchedule.CalendarCombo.DateButton();
            Infragistics.Win.Appearance appearance3 = new Infragistics.Win.Appearance();
            Infragistics.Win.Appearance appearance4 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.UltraToolbar ultraToolbar1 = new Infragistics.Win.UltraWinToolbars.UltraToolbar("mainMenu");
            Infragistics.Win.UltraWinToolbars.PopupMenuTool popupMenuTool1 = new Infragistics.Win.UltraWinToolbars.PopupMenuTool("File");
            Infragistics.Win.UltraWinToolbars.PopupMenuTool popupMenuTool2 = new Infragistics.Win.UltraWinToolbars.PopupMenuTool("Edit");
            Infragistics.Win.UltraWinToolbars.UltraToolbar ultraToolbar2 = new Infragistics.Win.UltraWinToolbars.UltraToolbar("mainToolbar");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool1 = new Infragistics.Win.UltraWinToolbars.ButtonTool("SaveAndClose");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool2 = new Infragistics.Win.UltraWinToolbars.ButtonTool("Delete");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool3 = new Infragistics.Win.UltraWinToolbars.ButtonTool("SaveAndClose");
            Infragistics.Win.Appearance appearance5 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool4 = new Infragistics.Win.UltraWinToolbars.ButtonTool("Delete");
            Infragistics.Win.Appearance appearance6 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.PopupMenuTool popupMenuTool3 = new Infragistics.Win.UltraWinToolbars.PopupMenuTool("File");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool5 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileSave");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool6 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileDelete");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool7 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileClose");
            Infragistics.Win.UltraWinToolbars.PopupMenuTool popupMenuTool4 = new Infragistics.Win.UltraWinToolbars.PopupMenuTool("Edit");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool8 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editUndo");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool9 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editCut");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool10 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editCopy");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool11 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editPaste");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool12 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editSelectAll");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool13 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileSave");
            Infragistics.Win.Appearance appearance7 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool14 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileDelete");
            Infragistics.Win.Appearance appearance8 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool15 = new Infragistics.Win.UltraWinToolbars.ButtonTool("fileClose");
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool16 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editUndo");
            Infragistics.Win.Appearance appearance9 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool17 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editCut");
            Infragistics.Win.Appearance appearance10 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool18 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editCopy");
            Infragistics.Win.Appearance appearance11 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool19 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editPaste");
            Infragistics.Win.Appearance appearance12 = new Infragistics.Win.Appearance();
            Infragistics.Win.UltraWinToolbars.ButtonTool buttonTool20 = new Infragistics.Win.UltraWinToolbars.ButtonTool("editSelectAll");
            Infragistics.Win.UltraWinTabControl.UltraTab ultraTab1 = new Infragistics.Win.UltraWinTabControl.UltraTab();
            Infragistics.Win.UltraWinTabControl.UltraTab ultraTab2 = new Infragistics.Win.UltraWinTabControl.UltraTab();
            this.ultraTabPageControl1 = new Infragistics.Win.UltraWinTabControl.UltraTabPageControl();
            this.txtRemarks = new Infragistics.Win.UltraWinEditors.UltraTextEditor();
            this.ultraLabel1 = new Infragistics.Win.Misc.UltraLabel();
            this.txtDescription = new Infragistics.Win.UltraWinEditors.UltraTextEditor();
            this.clrBarColor = new Infragistics.Win.UltraWinEditors.UltraColorPicker();
            this.lblBarColor = new Infragistics.Win.Misc.UltraLabel();
            this.cmdReminder = new Infragistics.Win.Misc.UltraButton();
            this.cboReminder = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.chkReminder = new Infragistics.Win.UltraWinEditors.UltraCheckEditor();
            this.ultraLabel2 = new Infragistics.Win.Misc.UltraLabel();
            this.chkAllDayEvent = new Infragistics.Win.UltraWinEditors.UltraCheckEditor();
            this.cboEndTime = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.cboStartTime = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.dtpEndTime = new Infragistics.Win.UltraWinSchedule.UltraCalendarCombo();
            this.dtpStartTime = new Infragistics.Win.UltraWinSchedule.UltraCalendarCombo();
            this.lblEndTime = new Infragistics.Win.Misc.UltraLabel();
            this.lblStartTime = new Infragistics.Win.Misc.UltraLabel();
            this.lblSeparator1 = new Infragistics.Win.Misc.UltraLabel();
            this.cboLabel = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.lblLabel = new Infragistics.Win.Misc.UltraLabel();
            this.cboLocation = new Infragistics.Win.UltraWinEditors.UltraComboEditor();
            this.txtSubject = new Infragistics.Win.UltraWinEditors.UltraTextEditor();
            this.lblLocation = new Infragistics.Win.Misc.UltraLabel();
            this.lblStatus = new Infragistics.Win.Misc.UltraLabel();
            this.lblSubject = new Infragistics.Win.Misc.UltraLabel();
            this.ultraTabPageControl2 = new Infragistics.Win.UltraWinTabControl.UltraTabPageControl();
            this.lvwScheduling = new System.Windows.Forms.ListView();
            this.subject = new System.Windows.Forms.ColumnHeader();
            this.location = new System.Windows.Forms.ColumnHeader();
            this.label = new System.Windows.Forms.ColumnHeader();
            this.startDate = new System.Windows.Forms.ColumnHeader();
            this.startTime = new System.Windows.Forms.ColumnHeader();
            this.endDate = new System.Windows.Forms.ColumnHeader();
            this.endTime = new System.Windows.Forms.ColumnHeader();
            this.allDayEvent = new System.Windows.Forms.ColumnHeader();
            this.ultraToolbarsManager1 = new Infragistics.Win.UltraWinToolbars.UltraToolbarsManager(this.components);
            this.Outlook2003AppointmentDialog_Fill_Panel = new System.Windows.Forms.Panel();
            this.ultraTabControl1 = new Infragistics.Win.UltraWinTabControl.UltraTabControl();
            this.ultraTabSharedControlsPage1 = new Infragistics.Win.UltraWinTabControl.UltraTabSharedControlsPage();
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom = new Infragistics.Win.UltraWinToolbars.UltraToolbarsDockArea();
            this.ultraTabPageControl1.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.txtRemarks)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtDescription)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.clrBarColor)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboReminder)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboEndTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboStartTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpEndTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpStartTime)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLabel)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLocation)).BeginInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtSubject)).BeginInit();
            this.ultraTabPageControl2.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.ultraToolbarsManager1)).BeginInit();
            this.Outlook2003AppointmentDialog_Fill_Panel.SuspendLayout();
            ((System.ComponentModel.ISupportInitialize)(this.ultraTabControl1)).BeginInit();
            this.ultraTabControl1.SuspendLayout();
            this.SuspendLayout();
            // 
            // ultraTabPageControl1
            // 
            this.ultraTabPageControl1.Controls.Add(this.txtRemarks);
            this.ultraTabPageControl1.Controls.Add(this.ultraLabel1);
            this.ultraTabPageControl1.Controls.Add(this.txtDescription);
            this.ultraTabPageControl1.Controls.Add(this.clrBarColor);
            this.ultraTabPageControl1.Controls.Add(this.lblBarColor);
            this.ultraTabPageControl1.Controls.Add(this.cmdReminder);
            this.ultraTabPageControl1.Controls.Add(this.cboReminder);
            this.ultraTabPageControl1.Controls.Add(this.chkReminder);
            this.ultraTabPageControl1.Controls.Add(this.ultraLabel2);
            this.ultraTabPageControl1.Controls.Add(this.chkAllDayEvent);
            this.ultraTabPageControl1.Controls.Add(this.cboEndTime);
            this.ultraTabPageControl1.Controls.Add(this.cboStartTime);
            this.ultraTabPageControl1.Controls.Add(this.dtpEndTime);
            this.ultraTabPageControl1.Controls.Add(this.dtpStartTime);
            this.ultraTabPageControl1.Controls.Add(this.lblEndTime);
            this.ultraTabPageControl1.Controls.Add(this.lblStartTime);
            this.ultraTabPageControl1.Controls.Add(this.lblSeparator1);
            this.ultraTabPageControl1.Controls.Add(this.cboLabel);
            this.ultraTabPageControl1.Controls.Add(this.lblLabel);
            this.ultraTabPageControl1.Controls.Add(this.cboLocation);
            this.ultraTabPageControl1.Controls.Add(this.txtSubject);
            this.ultraTabPageControl1.Controls.Add(this.lblLocation);
            this.ultraTabPageControl1.Controls.Add(this.lblStatus);
            this.ultraTabPageControl1.Controls.Add(this.lblSubject);
            this.ultraTabPageControl1.Location = new System.Drawing.Point(1, 23);
            this.ultraTabPageControl1.Name = "ultraTabPageControl1";
            this.ultraTabPageControl1.Size = new System.Drawing.Size(700, 402);
            // 
            // txtRemarks
            // 
            this.txtRemarks.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.txtRemarks.AutoSize = false;
            this.txtRemarks.Location = new System.Drawing.Point(509, 152);
            this.txtRemarks.Name = "txtRemarks";
            this.txtRemarks.Size = new System.Drawing.Size(162, 21);
            this.txtRemarks.TabIndex = 20;
            // 
            // ultraLabel1
            // 
            this.ultraLabel1.AutoSize = true;
            this.ultraLabel1.BackColorInternal = System.Drawing.Color.Transparent;
            this.ultraLabel1.Location = new System.Drawing.Point(445, 155);
            this.ultraLabel1.Name = "ultraLabel1";
            this.ultraLabel1.Size = new System.Drawing.Size(47, 15);
            this.ultraLabel1.TabIndex = 19;
            this.ultraLabel1.Text = "Remarks";
            // 
            // txtDescription
            // 
            this.txtDescription.AlwaysInEditMode = true;
            this.txtDescription.Anchor = ((System.Windows.Forms.AnchorStyles)((((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Bottom)
                        | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.txtDescription.Location = new System.Drawing.Point(8, 248);
            this.txtDescription.Multiline = true;
            this.txtDescription.Name = "txtDescription";
            this.txtDescription.Scrollbars = System.Windows.Forms.ScrollBars.Vertical;
            this.txtDescription.Size = new System.Drawing.Size(684, 146);
            this.txtDescription.TabIndex = 18;
            // 
            // clrBarColor
            // 
            this.clrBarColor.AutoSize = false;
            this.clrBarColor.Location = new System.Drawing.Point(336, 208);
            this.clrBarColor.Name = "clrBarColor";
            this.clrBarColor.Size = new System.Drawing.Size(150, 21);
            this.clrBarColor.TabIndex = 17;
            this.clrBarColor.Text = "Control";
            // 
            // lblBarColor
            // 
            this.lblBarColor.AutoSize = true;
            this.lblBarColor.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblBarColor.Location = new System.Drawing.Point(280, 212);
            this.lblBarColor.Name = "lblBarColor";
            this.lblBarColor.Size = new System.Drawing.Size(54, 15);
            this.lblBarColor.TabIndex = 16;
            this.lblBarColor.Text = "Bar Color:";
            // 
            // cmdReminder
            // 
            appearance1.Image = ((object)(resources.GetObject("appearance1.Image")));
            this.cmdReminder.Appearance = appearance1;
            this.cmdReminder.ImageTransparentColor = System.Drawing.Color.Magenta;
            this.cmdReminder.Location = new System.Drawing.Point(236, 208);
            this.cmdReminder.Name = "cmdReminder";
            this.cmdReminder.Size = new System.Drawing.Size(24, 23);
            this.cmdReminder.TabIndex = 15;
            this.cmdReminder.Text = "ultraButton1";
            this.cmdReminder.UseHotTracking = Infragistics.Win.DefaultableBoolean.True;
            this.cmdReminder.Click += new System.EventHandler(this.cmdReminder_Click);
            // 
            // cboReminder
            // 
            this.cboReminder.AutoSize = false;
            this.cboReminder.DropDownStyle = Infragistics.Win.DropDownStyle.DropDownList;
            this.cboReminder.Location = new System.Drawing.Point(96, 208);
            this.cboReminder.Name = "cboReminder";
            this.cboReminder.Size = new System.Drawing.Size(132, 21);
            this.cboReminder.TabIndex = 14;
            // 
            // chkReminder
            // 
            this.chkReminder.BackColor = System.Drawing.Color.Transparent;
            this.chkReminder.BackColorInternal = System.Drawing.Color.Transparent;
            this.chkReminder.Checked = true;
            this.chkReminder.CheckState = System.Windows.Forms.CheckState.Checked;
            this.chkReminder.Location = new System.Drawing.Point(17, 212);
            this.chkReminder.Name = "chkReminder";
            this.chkReminder.Size = new System.Drawing.Size(80, 16);
            this.chkReminder.TabIndex = 13;
            this.chkReminder.Text = "&Reminder:";
            this.chkReminder.UseMnemonics = true;
            this.chkReminder.CheckedChanged += new System.EventHandler(this.chkReminder_CheckedChanged);
            // 
            // ultraLabel2
            // 
            this.ultraLabel2.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance2.BackColor = System.Drawing.SystemColors.ControlDark;
            this.ultraLabel2.Appearance = appearance2;
            this.ultraLabel2.Location = new System.Drawing.Point(16, 188);
            this.ultraLabel2.Name = "ultraLabel2";
            this.ultraLabel2.Size = new System.Drawing.Size(676, 1);
            this.ultraLabel2.TabIndex = 15;
            // 
            // chkAllDayEvent
            // 
            this.chkAllDayEvent.BackColor = System.Drawing.Color.Transparent;
            this.chkAllDayEvent.BackColorInternal = System.Drawing.Color.Transparent;
            this.chkAllDayEvent.Location = new System.Drawing.Point(327, 132);
            this.chkAllDayEvent.Name = "chkAllDayEvent";
            this.chkAllDayEvent.Size = new System.Drawing.Size(88, 15);
            this.chkAllDayEvent.TabIndex = 12;
            this.chkAllDayEvent.Text = "All da&y event";
            this.chkAllDayEvent.UseMnemonics = true;
            this.chkAllDayEvent.CheckedChanged += new System.EventHandler(this.chkAllDayEvent_CheckedChanged);
            // 
            // cboEndTime
            // 
            this.cboEndTime.AutoSize = false;
            this.cboEndTime.Location = new System.Drawing.Point(240, 154);
            this.cboEndTime.Name = "cboEndTime";
            this.cboEndTime.Size = new System.Drawing.Size(78, 21);
            this.cboEndTime.TabIndex = 11;
            // 
            // cboStartTime
            // 
            this.cboStartTime.AutoSize = false;
            this.cboStartTime.Location = new System.Drawing.Point(240, 128);
            this.cboStartTime.Name = "cboStartTime";
            this.cboStartTime.Size = new System.Drawing.Size(78, 21);
            this.cboStartTime.TabIndex = 8;
            this.cboStartTime.ValueChanged += new System.EventHandler(this.cboStartTime_ValueChanged);
            // 
            // dtpEndTime
            // 
            this.dtpEndTime.BackColor = System.Drawing.SystemColors.Window;
            this.dtpEndTime.DateButtons.Add(dateButton1);
            this.dtpEndTime.Format = "ddd MM/d/yyyy";
            this.dtpEndTime.Location = new System.Drawing.Point(96, 154);
            this.dtpEndTime.Name = "dtpEndTime";
            this.dtpEndTime.NonAutoSizeHeight = 21;
            this.dtpEndTime.Size = new System.Drawing.Size(132, 21);
            this.dtpEndTime.TabIndex = 10;
            // 
            // dtpStartTime
            // 
            this.dtpStartTime.BackColor = System.Drawing.SystemColors.Window;
            this.dtpStartTime.DateButtons.Add(dateButton2);
            this.dtpStartTime.Format = "ddd MM/d/yyyy";
            this.dtpStartTime.Location = new System.Drawing.Point(96, 128);
            this.dtpStartTime.Name = "dtpStartTime";
            this.dtpStartTime.NonAutoSizeHeight = 21;
            this.dtpStartTime.Size = new System.Drawing.Size(132, 21);
            this.dtpStartTime.TabIndex = 7;
            // 
            // lblEndTime
            // 
            this.lblEndTime.AutoSize = true;
            this.lblEndTime.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblEndTime.Location = new System.Drawing.Point(16, 158);
            this.lblEndTime.Name = "lblEndTime";
            this.lblEndTime.Size = new System.Drawing.Size(55, 15);
            this.lblEndTime.TabIndex = 9;
            this.lblEndTime.Text = "End Time:";
            // 
            // lblStartTime
            // 
            this.lblStartTime.AutoSize = true;
            this.lblStartTime.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblStartTime.Location = new System.Drawing.Point(16, 132);
            this.lblStartTime.Name = "lblStartTime";
            this.lblStartTime.Size = new System.Drawing.Size(57, 15);
            this.lblStartTime.TabIndex = 6;
            this.lblStartTime.Text = "Start time:";
            // 
            // lblSeparator1
            // 
            this.lblSeparator1.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance3.BackColor = System.Drawing.SystemColors.ControlDark;
            this.lblSeparator1.Appearance = appearance3;
            this.lblSeparator1.Location = new System.Drawing.Point(16, 112);
            this.lblSeparator1.Name = "lblSeparator1";
            this.lblSeparator1.Size = new System.Drawing.Size(676, 1);
            this.lblSeparator1.TabIndex = 7;
            // 
            // cboLabel
            // 
            this.cboLabel.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.cboLabel.AutoSize = false;
            this.cboLabel.DropDownStyle = Infragistics.Win.DropDownStyle.DropDownList;
            this.cboLabel.Location = new System.Drawing.Point(457, 74);
            this.cboLabel.MaxDropDownItems = 11;
            this.cboLabel.Name = "cboLabel";
            this.cboLabel.Size = new System.Drawing.Size(236, 21);
            this.cboLabel.TabIndex = 5;
            // 
            // lblLabel
            // 
            this.lblLabel.AutoSize = true;
            this.lblLabel.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblLabel.Location = new System.Drawing.Point(423, 78);
            this.lblLabel.Name = "lblLabel";
            this.lblLabel.Size = new System.Drawing.Size(31, 15);
            this.lblLabel.TabIndex = 4;
            this.lblLabel.Text = "La&bel";
            this.lblLabel.WrapText = false;
            // 
            // cboLocation
            // 
            this.cboLocation.AutoSize = false;
            this.cboLocation.Location = new System.Drawing.Point(80, 74);
            this.cboLocation.Name = "cboLocation";
            this.cboLocation.Size = new System.Drawing.Size(336, 21);
            this.cboLocation.TabIndex = 3;
            this.cboLocation.KeyDown += new System.Windows.Forms.KeyEventHandler(this.cboLocation_KeyDown);
            // 
            // txtSubject
            // 
            this.txtSubject.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            this.txtSubject.AutoSize = false;
            this.txtSubject.Location = new System.Drawing.Point(80, 48);
            this.txtSubject.Name = "txtSubject";
            this.txtSubject.Size = new System.Drawing.Size(613, 21);
            this.txtSubject.TabIndex = 1;
            // 
            // lblLocation
            // 
            this.lblLocation.AutoSize = true;
            this.lblLocation.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblLocation.Location = new System.Drawing.Point(16, 78);
            this.lblLocation.Name = "lblLocation";
            this.lblLocation.Size = new System.Drawing.Size(50, 15);
            this.lblLocation.TabIndex = 2;
            this.lblLocation.Text = "&Location:";
            // 
            // lblStatus
            // 
            this.lblStatus.Anchor = ((System.Windows.Forms.AnchorStyles)(((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Left)
                        | System.Windows.Forms.AnchorStyles.Right)));
            appearance4.BackColor = System.Drawing.Color.FromArgb(((int)(((byte)(144)))), ((int)(((byte)(153)))), ((int)(((byte)(174)))));
            appearance4.BorderColor = System.Drawing.SystemColors.ControlDark;
            appearance4.ForeColor = System.Drawing.SystemColors.HighlightText;
            appearance4.TextHAlignAsString = "Left";
            this.lblStatus.Appearance = appearance4;
            this.lblStatus.BorderStyleOuter = Infragistics.Win.UIElementBorderStyle.Solid;
            this.lblStatus.Location = new System.Drawing.Point(6, 8);
            this.lblStatus.Name = "lblStatus";
            this.lblStatus.Size = new System.Drawing.Size(687, 21);
            this.lblStatus.TabIndex = 1;
            this.lblStatus.Text = "[Appointment status]";
            this.lblStatus.WrapText = false;
            // 
            // lblSubject
            // 
            this.lblSubject.AutoSize = true;
            this.lblSubject.BackColorInternal = System.Drawing.Color.Transparent;
            this.lblSubject.Location = new System.Drawing.Point(16, 51);
            this.lblSubject.Name = "lblSubject";
            this.lblSubject.Size = new System.Drawing.Size(45, 15);
            this.lblSubject.TabIndex = 0;
            this.lblSubject.Text = "Sub&ject:";
            // 
            // ultraTabPageControl2
            // 
            this.ultraTabPageControl2.Controls.Add(this.lvwScheduling);
            this.ultraTabPageControl2.Location = new System.Drawing.Point(-10000, -10000);
            this.ultraTabPageControl2.Name = "ultraTabPageControl2";
            this.ultraTabPageControl2.Size = new System.Drawing.Size(700, 402);
            // 
            // lvwScheduling
            // 
            this.lvwScheduling.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
            this.subject,
            this.location,
            this.label,
            this.startDate,
            this.startTime,
            this.endDate,
            this.endTime,
            this.allDayEvent});
            this.lvwScheduling.Dock = System.Windows.Forms.DockStyle.Fill;
            this.lvwScheduling.FullRowSelect = true;
            this.lvwScheduling.Location = new System.Drawing.Point(0, 0);
            this.lvwScheduling.MultiSelect = false;
            this.lvwScheduling.Name = "lvwScheduling";
            this.lvwScheduling.Size = new System.Drawing.Size(700, 402);
            this.lvwScheduling.Sorting = System.Windows.Forms.SortOrder.Ascending;
            this.lvwScheduling.TabIndex = 0;
            this.lvwScheduling.UseCompatibleStateImageBehavior = false;
            this.lvwScheduling.View = System.Windows.Forms.View.Details;
            // 
            // subject
            // 
            this.subject.Text = "Subject";
            // 
            // location
            // 
            this.location.Text = "Location";
            // 
            // label
            // 
            this.label.Text = "Label";
            // 
            // startDate
            // 
            this.startDate.Text = "Start Date";
            // 
            // startTime
            // 
            this.startTime.Text = "Start Time";
            // 
            // endDate
            // 
            this.endDate.Text = "End Date";
            // 
            // endTime
            // 
            this.endTime.Text = "End Time";
            // 
            // allDayEvent
            // 
            this.allDayEvent.Text = "All Day Event";
            // 
            // ultraToolbarsManager1
            // 
            this.ultraToolbarsManager1.DesignerFlags = 1;
            this.ultraToolbarsManager1.DockWithinContainer = this;
            this.ultraToolbarsManager1.DockWithinContainerBaseType = typeof(System.Windows.Forms.Form);
            this.ultraToolbarsManager1.ImageTransparentColor = System.Drawing.Color.Magenta;
            this.ultraToolbarsManager1.ShowFullMenusDelay = 500;
            this.ultraToolbarsManager1.Style = Infragistics.Win.UltraWinToolbars.ToolbarStyle.Office2003;
            ultraToolbar1.DockedColumn = 0;
            ultraToolbar1.DockedRow = 0;
            ultraToolbar1.IsMainMenuBar = true;
            ultraToolbar1.NonInheritedTools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            popupMenuTool1,
            popupMenuTool2});
            ultraToolbar1.Text = "mainMenu";
            ultraToolbar2.DockedColumn = 0;
            ultraToolbar2.DockedRow = 1;
            ultraToolbar2.NonInheritedTools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool1,
            buttonTool2});
            ultraToolbar2.Text = "Standard";
            this.ultraToolbarsManager1.Toolbars.AddRange(new Infragistics.Win.UltraWinToolbars.UltraToolbar[] {
            ultraToolbar1,
            ultraToolbar2});
            appearance5.Image = ((object)(resources.GetObject("appearance5.Image")));
            buttonTool3.SharedProps.AppearancesSmall.Appearance = appearance5;
            buttonTool3.SharedProps.Caption = "&Save and Close";
            buttonTool3.SharedProps.DisplayStyle = Infragistics.Win.UltraWinToolbars.ToolDisplayStyle.ImageAndText;
            buttonTool3.SharedProps.ToolTipText = "Save and Close";
            appearance6.Image = ((object)(resources.GetObject("appearance6.Image")));
            buttonTool4.SharedProps.AppearancesSmall.Appearance = appearance6;
            buttonTool4.SharedProps.Caption = "Delete";
            buttonTool4.SharedProps.DisplayStyle = Infragistics.Win.UltraWinToolbars.ToolDisplayStyle.ImageOnlyOnToolbars;
            buttonTool4.SharedProps.ToolTipText = "Delete";
            popupMenuTool3.SharedProps.Caption = "&File";
            buttonTool6.InstanceProps.IsFirstInGroup = true;
            buttonTool7.InstanceProps.IsFirstInGroup = true;
            popupMenuTool3.Tools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool5,
            buttonTool6,
            buttonTool7});
            popupMenuTool4.SharedProps.Caption = "&Edit";
            buttonTool12.InstanceProps.IsFirstInGroup = true;
            popupMenuTool4.Tools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool8,
            buttonTool9,
            buttonTool10,
            buttonTool11,
            buttonTool12});
            appearance7.Image = ((object)(resources.GetObject("appearance7.Image")));
            buttonTool13.SharedProps.AppearancesSmall.Appearance = appearance7;
            buttonTool13.SharedProps.Caption = "&Save";
            buttonTool13.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlS;
            appearance8.Image = ((object)(resources.GetObject("appearance8.Image")));
            buttonTool14.SharedProps.AppearancesSmall.Appearance = appearance8;
            buttonTool14.SharedProps.Caption = "&Delete";
            buttonTool14.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlD;
            buttonTool15.SharedProps.Caption = "&Close";
            buttonTool15.SharedProps.Shortcut = System.Windows.Forms.Shortcut.AltF4;
            appearance9.Image = ((object)(resources.GetObject("appearance9.Image")));
            buttonTool16.SharedProps.AppearancesSmall.Appearance = appearance9;
            buttonTool16.SharedProps.Caption = "&Undo";
            buttonTool16.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlZ;
            appearance10.Image = ((object)(resources.GetObject("appearance10.Image")));
            buttonTool17.SharedProps.AppearancesSmall.Appearance = appearance10;
            buttonTool17.SharedProps.Caption = "Cu&t";
            buttonTool17.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlX;
            appearance11.Image = ((object)(resources.GetObject("appearance11.Image")));
            buttonTool18.SharedProps.AppearancesSmall.Appearance = appearance11;
            buttonTool18.SharedProps.Caption = "&Copy";
            buttonTool18.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlC;
            appearance12.Image = ((object)(resources.GetObject("appearance12.Image")));
            buttonTool19.SharedProps.AppearancesSmall.Appearance = appearance12;
            buttonTool19.SharedProps.Caption = "&Paste";
            buttonTool19.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlV;
            buttonTool20.SharedProps.Caption = "Select A&ll";
            buttonTool20.SharedProps.Shortcut = System.Windows.Forms.Shortcut.CtrlA;
            this.ultraToolbarsManager1.Tools.AddRange(new Infragistics.Win.UltraWinToolbars.ToolBase[] {
            buttonTool3,
            buttonTool4,
            popupMenuTool3,
            popupMenuTool4,
            buttonTool13,
            buttonTool14,
            buttonTool15,
            buttonTool16,
            buttonTool17,
            buttonTool18,
            buttonTool19,
            buttonTool20});
            this.ultraToolbarsManager1.ToolClick += new Infragistics.Win.UltraWinToolbars.ToolClickEventHandler(this.ultraToolbarsManager1_ToolClick);
            this.ultraToolbarsManager1.BeforeToolDropdown += new Infragistics.Win.UltraWinToolbars.BeforeToolDropdownEventHandler(this.ultraToolbarsManager1_BeforeToolDropdown);
            // 
            // Outlook2003AppointmentDialog_Fill_Panel
            // 
            this.Outlook2003AppointmentDialog_Fill_Panel.Controls.Add(this.ultraTabControl1);
            this.Outlook2003AppointmentDialog_Fill_Panel.Cursor = System.Windows.Forms.Cursors.Default;
            this.Outlook2003AppointmentDialog_Fill_Panel.Dock = System.Windows.Forms.DockStyle.Fill;
            this.Outlook2003AppointmentDialog_Fill_Panel.Location = new System.Drawing.Point(0, 50);
            this.Outlook2003AppointmentDialog_Fill_Panel.Name = "Outlook2003AppointmentDialog_Fill_Panel";
            this.Outlook2003AppointmentDialog_Fill_Panel.Size = new System.Drawing.Size(704, 428);
            this.Outlook2003AppointmentDialog_Fill_Panel.TabIndex = 0;
            // 
            // ultraTabControl1
            // 
            this.ultraTabControl1.Controls.Add(this.ultraTabSharedControlsPage1);
            this.ultraTabControl1.Controls.Add(this.ultraTabPageControl1);
            this.ultraTabControl1.Controls.Add(this.ultraTabPageControl2);
            this.ultraTabControl1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.ultraTabControl1.Location = new System.Drawing.Point(0, 0);
            this.ultraTabControl1.Name = "ultraTabControl1";
            this.ultraTabControl1.SharedControlsPage = this.ultraTabSharedControlsPage1;
            this.ultraTabControl1.Size = new System.Drawing.Size(704, 428);
            this.ultraTabControl1.TabIndex = 5;
            ultraTab1.Key = "Appointment";
            ultraTab1.TabPage = this.ultraTabPageControl1;
            ultraTab1.Text = "Appointment";
            ultraTab2.Key = "Scheduling";
            ultraTab2.TabPage = this.ultraTabPageControl2;
            ultraTab2.Text = "Scheduling";
            this.ultraTabControl1.Tabs.AddRange(new Infragistics.Win.UltraWinTabControl.UltraTab[] {
            ultraTab1,
            ultraTab2});
            this.ultraTabControl1.UseHotTracking = Infragistics.Win.DefaultableBoolean.True;
            this.ultraTabControl1.SelectedTabChanged += new Infragistics.Win.UltraWinTabControl.SelectedTabChangedEventHandler(this.ultraTabControl1_SelectedTabChanged);
            // 
            // ultraTabSharedControlsPage1
            // 
            this.ultraTabSharedControlsPage1.Location = new System.Drawing.Point(-10000, -10000);
            this.ultraTabSharedControlsPage1.Name = "ultraTabSharedControlsPage1";
            this.ultraTabSharedControlsPage1.Size = new System.Drawing.Size(700, 402);
            // 
            // _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left
            // 
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.BackColor = System.Drawing.SystemColors.Control;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Left;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.ForeColor = System.Drawing.SystemColors.ControlText;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.Location = new System.Drawing.Point(0, 50);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.Name = "_Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left";
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.Size = new System.Drawing.Size(0, 428);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right
            // 
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.BackColor = System.Drawing.SystemColors.Control;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Right;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.ForeColor = System.Drawing.SystemColors.ControlText;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.Location = new System.Drawing.Point(704, 50);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.Name = "_Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right";
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.Size = new System.Drawing.Size(0, 428);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top
            // 
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.BackColor = System.Drawing.SystemColors.Control;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Top;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.ForeColor = System.Drawing.SystemColors.ControlText;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.Location = new System.Drawing.Point(0, 0);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.Name = "_Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top";
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.Size = new System.Drawing.Size(704, 50);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // _Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom
            // 
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.AccessibleRole = System.Windows.Forms.AccessibleRole.Grouping;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.BackColor = System.Drawing.SystemColors.Control;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.DockedPosition = Infragistics.Win.UltraWinToolbars.DockedPosition.Bottom;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.ForeColor = System.Drawing.SystemColors.ControlText;
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.Location = new System.Drawing.Point(0, 478);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.Name = "_Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom";
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.Size = new System.Drawing.Size(704, 0);
            this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom.ToolbarsManager = this.ultraToolbarsManager1;
            // 
            // Outlook2003AppointmentDialog
            // 
            this.AutoScaleBaseSize = new System.Drawing.Size(5, 14);
            this.ClientSize = new System.Drawing.Size(704, 478);
            this.Controls.Add(this.Outlook2003AppointmentDialog_Fill_Panel);
            this.Controls.Add(this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Left);
            this.Controls.Add(this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Right);
            this.Controls.Add(this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Top);
            this.Controls.Add(this._Outlook2003AppointmentDialog_Toolbars_Dock_Area_Bottom);
            this.Font = new System.Drawing.Font("Tahoma", 8.25F, System.Drawing.FontStyle.Regular, System.Drawing.GraphicsUnit.Point, ((byte)(0)));
            this.Icon = ((System.Drawing.Icon)(resources.GetObject("$this.Icon")));
            this.MinimumSize = new System.Drawing.Size(560, 432);
            this.Name = "Outlook2003AppointmentDialog";
            this.Text = "Untitled - Appointment";
            this.Closing += new System.ComponentModel.CancelEventHandler(this.Outlook2003AppointmentDialog_Closing);
            this.ultraTabPageControl1.ResumeLayout(false);
            this.ultraTabPageControl1.PerformLayout();
            ((System.ComponentModel.ISupportInitialize)(this.txtRemarks)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtDescription)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.clrBarColor)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboReminder)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboEndTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboStartTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpEndTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.dtpStartTime)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLabel)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.cboLocation)).EndInit();
            ((System.ComponentModel.ISupportInitialize)(this.txtSubject)).EndInit();
            this.ultraTabPageControl2.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.ultraToolbarsManager1)).EndInit();
            this.Outlook2003AppointmentDialog_Fill_Panel.ResumeLayout(false);
            ((System.ComponentModel.ISupportInitialize)(this.ultraTabControl1)).EndInit();
            this.ultraTabControl1.ResumeLayout(false);
            this.ResumeLayout(false);
            this.Load += new EventHandler(Outlook2003AppointmentDialog_Load);

		}

        void Outlook2003AppointmentDialog_Load(object sender, EventArgs e)
        {

            // added by Loo 13-03-2009 for owner key
            strOwnerKey = this.appointment.OwnerKey;
        }

		#endregion Windows Form Designer generated code

		#region Main()
		/*
		/// <summary>
		/// The main entry point for the application.
		/// </summary>
		[STAThread]
		static void Main() 
		{
			Application.Run(new Outlook2003AppointmentDialog());
		}
		*/
		#endregion Main()

		#region Internal properties/methods

		#region InitializeUI
		private void InitializeUI()
		{
			this.PopulateAppointmentLabelCombo();
			this.PopulateStartTimeAndEndTimeCombos();
			this.PopulateReminderCombo();
			this.PopulateLocationCombo();

			if ( this.appointment != null )
			{
				//	Set the dialog's title
				if ( this.isExistingAppointment )
				{
					if ( this.appointment.AllDayEvent )
						this.Text = this.appointment.Subject + " - Event";
					else
						this.Text = this.appointment.Subject + " - Appointment";
				}
				else
				{
					if ( this.appointment.AllDayEvent )
						this.Text = "Untitled - Event";
					else
						this.Text = "Untitled - Appointment";
				}

				//	Subject
				this.txtSubject.Text = this.appointment.Subject;

				//	Location
				this.cboLocation.Text = this.appointment.Location;

				//	Get the ExtendedAppointmentInfo object from the
				//	Tag property, if there is one
				ExtendedAppointmentInfo info = this.appointment.Tag as ExtendedAppointmentInfo;

				if ( info != null && info.Label != null )
					this.cboLabel.Text = info.Label.DisplayText;
				else
					this.cboLabel.SelectedIndex = 0;

                // added by Loo 06-03-2009
                if (info != null && info.Remarks != null)
                {
                    this.txtRemarks.Text = info.Remarks;
                }
                // end

				//	Starting date
				this.dtpStartTime.Value = this.appointment.StartDateTime;

				//	Ending date
				this.dtpEndTime.Value = this.appointment.EndDateTime;

				//	AllDayEvent
				this.chkAllDayEvent.Checked = this.appointment.AllDayEvent;

				if ( ! this.appointment.AllDayEvent )
					this.VerifyAppointmentStartAndEndTime();

				//	Set the status label's text, or hide it, as appropriate
				this.VerifyAppointmentStatus();

				//	If there is a reminder, select the appropriate
				//	item in the combo. Note that we are only supporting
				//	the values that appear in the reminder time combo's
				//	dropdown list; more sophisticated parsing methods can
				//	be employed here to support all possible times.
				if ( this.appointment.HasReminder && this.appointment.Reminder.Enabled )
				{
					Reminder reminder = this.appointment.Reminder;
					int multiplier = 1;
					switch( reminder.DisplayIntervalUnits )
					{
						case DisplayIntervalUnits.Minutes:
						{
							multiplier = 1;
							break;
						}
						case DisplayIntervalUnits.Hours:
						{
							multiplier = 60;
							break;
						}
						case DisplayIntervalUnits.Days:
						{
							multiplier = 1440;
							break;
						}
						case DisplayIntervalUnits.Months:
						{
							//	Base this on a 30-day month
							multiplier = 43200;
							break;
						}
					}

					//	Set the value of the Reminder combo to the TimeSpan we get
					//	when we multiply the DisplayInterval by the unit of time.
					TimeSpan reminderTime = new TimeSpan(0, reminder.DisplayInterval * multiplier, 0);
					this.cboReminder.Value = reminderTime;

					//	If the result did not match any of the items in the
					//	list, default to 15 minutes.
					if ( this.cboReminder.SelectedIndex == -1 )
						this.cboReminder.Value = new TimeSpan(0, 15, 0);
				}
				else
				{
					this.cboReminder.Value = new TimeSpan(0, 15, 0);

					if ( this.isExistingAppointment )
						this.chkReminder.Checked = false;
				}

				//	Description
				this.txtDescription.Text = this.appointment.Description;

				//	Bar color
				this.clrBarColor.Color = this.appointment.BarColor;
			}
		}
		#endregion InitializeUI

		#region VerifyAppointmentStatus
		private void VerifyAppointmentStatus()
		{
			if ( this.appointment.StartDateTime < DateTime.Now )
				this.lblStatus.Text = Outlook2003AppointmentDialog.APPOINTMENT_IN_THE_PAST;
			else
			if ( this.calendarInfo != null &&
				 this.calendarInfo.GetAppointmentsInRange( this.appointment.StartDateTime, this.appointment.EndDateTime ).Count > 0 )
				this.lblStatus.Text = Outlook2003AppointmentDialog.APPOINTMENT_CONFLICTS;
			//	Add any custom statuses before the final 'else' clause
			else
			{
				this.lblStatus.Text = string.Empty;
				this.lblStatus.Visible = false;
			}

		}
		#endregion VerifyAppointmentStatus

		#region VerifyAppointmentStartAndEndTime
		private void VerifyAppointmentStartAndEndTime()
		{
			this.cboStartTime.Text = this.appointment.StartDateTime.ToShortTimeString();
			this.cboEndTime.Text = this.appointment.EndDateTime.ToShortTimeString();
		}
		#endregion VerifyAppointmentStartAndEndTime

		#region PopulateAppointmentLabelCombo
		private void PopulateAppointmentLabelCombo()
		{
			#region Notes
			//
			//	The currently supported values are as follows:
			//
			//	None				Color.Transparent
			//	Important			255, 248, 132
			//	Business			132, 156, 231
			//	Personal			165, 222, 99
			//	Vacation			231, 231, 214		
			//	MustAttend			255, 181, 115		
			//	TravelRequired		132, 239, 247
			//	NeedsPreparation	214, 206, 132
			//	Birthday			198, 165, 247
			//	Anniversary			165, 206, 198
			//	PhoneCall			255, 231, 115
			//
			#endregion Notes

			ValueListItemsCollection valueListItemsCollection = this.cboLabel.Items;
			valueListItemsCollection.Clear();

			ValueListItem item = null;
			item = valueListItemsCollection.Add( new AppointmentLabel( "None", Color.Transparent ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Important", Color.FromArgb(255, 248, 132) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Business", Color.FromArgb(132, 156, 231) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Personal", Color.FromArgb(165, 222, 99) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Vacation", Color.FromArgb(231, 231, 214) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "MustAttend", Color.FromArgb(255, 181, 115) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "TravelRequired", Color.FromArgb(132, 239, 247) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "NeedsPreparation", Color.FromArgb(214, 206, 132) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Birthday", Color.FromArgb(198, 165, 247) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "Anniversary", Color.FromArgb(165, 206, 198) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;
			item = valueListItemsCollection.Add( new AppointmentLabel( "PhoneCall", Color.FromArgb(255, 231, 115) ) );
			item.Appearance.Image = ((AppointmentLabel)item.DataValue).Image;

		}
		#endregion PopulateAppointmentLabelCombo

		#region PopulateStartTimeAndEndTimeCombos		
		private void PopulateStartTimeAndEndTimeCombos()
		{
			this.cboStartTime.Items.Clear();
			this.cboEndTime.Items.Clear();

			DateTime theDate = new DateTime( DateTime.Today.Year, DateTime.Today.Month, DateTime.Today.Day, 0, 0, 0 );
			for ( int i = 0; i < 48; i ++ )
			{
				this.cboStartTime.Items.Add( theDate.ToShortTimeString() );
				this.cboEndTime.Items.Add( theDate.ToShortTimeString() );
				theDate = theDate.AddMinutes( 30f );
			}
		}
		#endregion PopulateStartTimeAndEndTimeCombos

		#region PopulateReminderCombo
		private void PopulateReminderCombo()
		{
			this.cboReminder.Items.Clear();
			this.cboReminder.Items.Add( TimeSpan.Zero, "0 minutes" );
			this.cboReminder.Items.Add( new TimeSpan(0, 5, 0), "5 minutes" );
			this.cboReminder.Items.Add( new TimeSpan(0, 10, 0), "10 minutes" );
			this.cboReminder.Items.Add( new TimeSpan(0, 15, 0), "15 minutes" );
			this.cboReminder.Items.Add( new TimeSpan(0, 30, 0), "30 minutes" );
			this.cboReminder.Items.Add( new TimeSpan(1, 0, 0), "1 hour" );
			this.cboReminder.Items.Add( new TimeSpan(2, 0, 0), "2 hours" );
			this.cboReminder.Items.Add( new TimeSpan(3, 0, 0), "3 hours" );
			this.cboReminder.Items.Add( new TimeSpan(4, 0, 0), "4 hours" );
			this.cboReminder.Items.Add( new TimeSpan(5, 0, 0), "5 hours" );
			this.cboReminder.Items.Add( new TimeSpan(6, 0, 0), "6 hours" );
			this.cboReminder.Items.Add( new TimeSpan(7, 0, 0), "7 hours" );
			this.cboReminder.Items.Add( new TimeSpan(8, 0, 0), "8 hours" );
			this.cboReminder.Items.Add( new TimeSpan(9, 0, 0), "9 hours" );
			this.cboReminder.Items.Add( new TimeSpan(10, 0, 0), "10 hours" );
			this.cboReminder.Items.Add( new TimeSpan(11, 0, 0), "1 hours" );
			this.cboReminder.Items.Add( new TimeSpan(12, 0, 0), ".5 days" );
			this.cboReminder.Items.Add( new TimeSpan(18, 0, 0), "18 hours" );
			this.cboReminder.Items.Add( new TimeSpan(1, 0, 0, 0), "1 day" );
			this.cboReminder.Items.Add( new TimeSpan(2, 0, 0, 0), "2 days" );
			this.cboReminder.Items.Add( new TimeSpan(3, 0, 0, 0), "3 days" );
			this.cboReminder.Items.Add( new TimeSpan(4, 0, 0, 0), "4 days" );
			this.cboReminder.Items.Add( new TimeSpan(7, 0, 0, 0), "1 week" );
			this.cboReminder.Items.Add( new TimeSpan(14, 0, 0, 0), "2 weeks" );
		}
		#endregion PopulateReminderCombo

		#region SaveAppointment
		private void SaveAppointment()
		{
            // added by Loo 13-03-2009 for owner key
            this.appointment.OwnerKey = strOwnerKey;

			//	Subject
			this.appointment.Subject = this.txtSubject.Text;

			//	Location
			this.appointment.Location = this.cboLocation.Text;
			
			//	StartDateTime
			try
			{
				DateTime tempStartTime = DateTime.Parse( this.cboStartTime.Text );
				DateTime tempStartDate = (DateTime)this.dtpStartTime.Value;
				this.appointment.StartDateTime = new DateTime( tempStartDate.Year, tempStartDate.Month, tempStartDate.Day, tempStartTime.Hour, tempStartTime.Minute, 0 );
			}
			catch
			{
				//	If we couldn't successfully parse the date, revert to the time
				//	of the original, untouched appointment.
				this.appointment.StartDateTime = this.oldAppointment.StartDateTime;
			}

			//	StartDateTime
			try
			{
				DateTime tempEndTime = DateTime.Parse( this.cboEndTime.Text );
				DateTime tempEndDate = (DateTime)this.dtpEndTime.Value;
				this.appointment.EndDateTime = new DateTime( tempEndDate.Year, tempEndDate.Month, tempEndDate.Day, tempEndTime.Hour, tempEndTime.Minute, 0 );
			}
			catch
			{
				//	If we couldn't successfully parse the date, revert to the time
				//	of the original, untouched appointment.
				this.appointment.EndDateTime = this.oldAppointment.EndDateTime;
			}

			//	AllDayEvent
			this.appointment.AllDayEvent = this.chkAllDayEvent.Checked;

			//	Reminder
			if ( this.chkReminder.Checked )
			{
				this.appointment.Reminder.DisplayIntervalUnits = DisplayIntervalUnits.Minutes;
				TimeSpan reminderDisplayInterval = (TimeSpan)this.cboReminder.SelectedItem.DataValue;
				this.appointment.Reminder.DisplayInterval = (int)reminderDisplayInterval.TotalMinutes;
				this.appointment.Reminder.Enabled = true;
			}
			else
				this.appointment.Reminder = null;

			//	BarColor
			this.appointment.BarColor = this.clrBarColor.Color;

			//	ExtendedAppointmentInfo
			//
			//	First, see if the Appointment already has an ExtendedAppointmentInfo;
			//	if it does, we will continue to use it.
			ExtendedAppointmentInfo info = this.appointment.Tag as ExtendedAppointmentInfo;
			if ( info == null )
				info = new ExtendedAppointmentInfo( this.appointment );

			//	Assign the value in the Label combo to the
			//	ExtendedAppointmentInfo object's Label property
			info.Label = this.cboLabel.SelectedItem == null ? null : this.cboLabel.SelectedItem.DataValue as AppointmentLabel;
			
			if ( this.cboLabel.SelectedIndex > 0 )
			{
				//	Assign the color for the label item to the BackColor property
				//	of the Appointment's Appearance.
				this.appointment.Appearance.BackColor = info.Label.Color;
				this.appointment.Appearance.ForeColor = SystemColors.WindowText;
			}
			else
				this.appointment.Appearance.Reset();

            // Customer 
            info.Remarks = this.txtRemarks.Text;
            // end

			//	Store the ExtendedAppointmentInfo object in the Appointment's Tag
			this.appointment.Tag = info;

			this.appointment.Description = this.txtDescription.Text;

			//	If the appointment does not belong to the CalendarInfo's Appointments
			//	collection, we must clone it and add it.
			if ( ! this.isExistingAppointment )
			{
				//	Add the appointment				
				Appointment addedAppointment = this.calendarInfo.Appointments.Add( ((ICloneable)this.appointment).Clone() as Appointment );

				//	Update the member variable to reflect the fact that the Appointment
				//	now belongs to the CalendarInfo's Appointments collection, so we know
				//	not to add it again in the event that it is saved more than once in a
				//	dialog session.
				this.isExistingAppointment = this.calendarInfo.Appointments.Contains( addedAppointment );

				//	Make sure the appointment was successfully added (i.e., the
				//	BeforeAppointmentAdded event was not canceled).
				if ( this.isExistingAppointment )
				{
					//	Reassign the member that holds a reference to the appointment
					this.appointment = addedAppointment;
					this.oldAppointment = this.appointment;
				}

			}
		}
		#endregion SaveAppointment

		#region VerifyMenuItemsEnabledState
		private void VerifyMenuItemsEnabledState()
		{
			ButtonTool buttonTool = null;

			//	Disable all button tools under the 'Edit' menu and work backwards from there
			PopupMenuTool editMenu = this.ultraToolbarsManager1.Tools["Edit"] as PopupMenuTool;
			foreach( ToolBase tool in editMenu.Tools )
			{
				buttonTool = tool as ButtonTool;
				if ( buttonTool == null )
					continue;

				buttonTool.SharedProps.Enabled = false;
			}

			EmbeddableTextBox activeControl = this.ActiveControl as EmbeddableTextBox;
			if ( activeControl == null )
				return;

			//	Undo
			if ( activeControl.Modified )
			{
				buttonTool = this.ultraToolbarsManager1.Tools["editUndo"] as ButtonTool;
				buttonTool.SharedProps.Enabled = true;
			}

			IDataObject dataObject = Clipboard.GetDataObject();
			bool clipboardHasText = dataObject.GetDataPresent( typeof(string) );

			//	Cut/Copy
			if ( activeControl.SelectionLength > 0 )
			{
				buttonTool = this.ultraToolbarsManager1.Tools["editCopy"] as ButtonTool;
				buttonTool.SharedProps.Enabled = true;

				buttonTool = this.ultraToolbarsManager1.Tools["editCut"] as ButtonTool;
				buttonTool.SharedProps.Enabled = true;
			}

			//	Paste
			if ( clipboardHasText )
			{
				buttonTool = this.ultraToolbarsManager1.Tools["editPaste"] as ButtonTool;
				buttonTool.SharedProps.Enabled = true;
			}

			//	SelectAll
			buttonTool = this.ultraToolbarsManager1.Tools["editSelectAll"] as ButtonTool;
			buttonTool.SharedProps.Enabled = true;

		}
		#endregion VerifyMenuItemsEnabledState

		#region PopulateSchedulingListView
		private void PopulateSchedulingListView()
		{
			//	Clear the Items collection
			this.lvwScheduling.Items.Clear();

			//	Set the column widths
			int defaultWidth = (this.lvwScheduling.Width - 260) / (this.lvwScheduling.Columns.Count - 1);
			foreach( ColumnHeader header in this.lvwScheduling.Columns )
			{
				if ( header.Index == 0 )
					header.Width = 250;
				else
					header.Width = defaultWidth;
			}

			//	Iterate the Appointments collection, and add an item for each Appointment
			foreach( Appointment appointment in this.calendarInfo.Appointments )
			{
				//	Subject
				ListViewItem lvItem = this.lvwScheduling.Items.Add( appointment.Subject );

				//	Location
				if ( appointment.Location != null && appointment.Location.Length > 0 )
					lvItem.SubItems.Add( appointment.Location );
				else
					lvItem.SubItems.Add( "None" );

				//	Label
				ExtendedAppointmentInfo info = appointment.Tag as ExtendedAppointmentInfo;
				if ( info != null && info.Label != null )
					lvItem.SubItems.Add( info.Label.DisplayText );
				else
					lvItem.SubItems.Add( "None" );

				//	StartDateTime
				lvItem.SubItems.Add( appointment.StartDateTime.ToShortDateString() );
				lvItem.SubItems.Add( appointment.StartDateTime.ToShortTimeString() );

				//	EndDateTime
				lvItem.SubItems.Add( appointment.EndDateTime.ToShortDateString() );
				lvItem.SubItems.Add( appointment.EndDateTime.ToShortTimeString() );

				//	AllDayEvent
				if ( appointment.AllDayEvent )
					lvItem.SubItems.Add( "Yes" );
				else
					lvItem.SubItems.Add( "No" );

				//	If the appointment is past due, set the ForeColor to red
				if ( appointment.StartDateTime < DateTime.Now )
					lvItem.ForeColor = Color.Red;
				
			}
		}
		#endregion PopulateSchedulingListView

		#region PopulateLocationCombo
		private void PopulateLocationCombo()
		{
			this.cboLocation.Items.Clear();

			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( Outlook2003AppointmentDialog.APP_REGISTRY_PATH + @"\LocationList" );
			string [] regKeys = regKey.GetSubKeyNames();
			string keyName = null;

			for ( int i = 0; i < regKeys.Length; i ++ )
			{
				keyName = regKeys[ i ];
				if ( keyName != null )
					this.cboLocation.Items.Add( keyName );
			}
		}
		#endregion PopulateLocationCombo

		#region SaveLocationsToRegistry
		private void SaveLocationsToRegistry()
		{
			//	Clear the location list from the registry
			this.ClearLocationsFromRegistry();

			//	Re-create the 'LocationList' subkey
			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( Outlook2003AppointmentDialog.APP_REGISTRY_PATH );
			RegistryKey locationListKey = regKey.CreateSubKey( "LocationList" );

			//	Iterate the Items collection, and add each entry to the registry
			for ( int i = 0; i < this.cboLocation.Items.Count; i ++ )
			{
				ValueListItem item = this.cboLocation.Items[i];
				locationListKey.CreateSubKey( item.DataValue as string );
			}
		}
		#endregion SaveLocationsToRegistry

		#region ClearLocationsFromRegistry
		private void ClearLocationsFromRegistry()
		{
			//	Clear the location list from the registry
			RegistryKey regKey = null;
			regKey = Registry.LocalMachine.CreateSubKey( Outlook2003AppointmentDialog.APP_REGISTRY_PATH );
			regKey.DeleteSubKeyTree( "LocationList" );
		}
		#endregion ClearLocationsFromRegistry

		#endregion Internal properties/methods

		#region Public Properties / Methods

			#region Show
		/// <summary>
		/// Displays the dialog for the specified Appointment.
		/// </summary>
		/// <param name="appointment">The appointment to be created/edited.</param>
		/// <param name="calendarInfo">The UltraCalendarInfo object to which the appointment is to be associated.</param>
		public void Show( Appointment appointment, UltraCalendarInfo calendarInfo )
		{
			//	Ensure that the parameters are valid, active objects
			if ( appointment == null )
				throw new Exception( Outlook2003AppointmentDialog.NULL_APPOINTMENT_EXCEPTION );

			if ( calendarInfo == null )
				throw new Exception( Outlook2003AppointmentDialog.NULL_CALENDAR_INFO_EXCEPTION );

			//	Display a wait cursor while the dialog is initializing
			Cursor.Current = Cursors.WaitCursor;

			//	Ensure that we are not dealing with an Appointment from some other
			//	UltraCalendarInfo object, which we don't support here.
			if ( appointment.CalendarInfo != null &&
				 appointment.CalendarInfo != calendarInfo )
				throw new Exception( Outlook2003AppointmentDialog.NON_ASSOCIATED_CALENDAR_INFO_EXCEPTION );

			//	Set the private members
			this.appointment = appointment;
			this.oldAppointment = this.appointment;
			this.calendarInfo = calendarInfo;

			this.isExistingAppointment =  ( this.calendarInfo != null &&
											this.calendarInfo.Appointments.Contains( this.appointment ) );
			
			//	Initialize the user interface
			this.InitializeUI();

			//	Display the dialog
			this.Show();

			//	Clear the wait cursor
			this.BringToFront();
		}
			#endregion Show

		#endregion Public Properties / Methods

		private void ultraToolbarsManager1_BeforeToolDropdown(object sender, Infragistics.Win.UltraWinToolbars.BeforeToolDropdownEventArgs e)
		{
			switch( e.Tool.Key )
			{
				case "Edit":
				{
					this.VerifyMenuItemsEnabledState();
				}
				break;
			}
		}

		private void ultraToolbarsManager1_ToolClick(object sender, Infragistics.Win.UltraWinToolbars.ToolClickEventArgs e)
		{
			bool closeDialog = false;
			EmbeddableTextBox activeControl = this.ActiveControl as EmbeddableTextBox;

			switch( e.Tool.Key )
			{
				case "fileSave":
				case "SaveAndClose":
				{
					closeDialog = e.Tool.Key == "SaveAndClose";
					
					if ( closeDialog )
					{
						//	Verify the start time
						try
						{
							DateTime tempStartTime = DateTime.Parse( this.cboStartTime.Text );
						}
						catch
						{
							MessageBox.Show( Outlook2003AppointmentDialog.INVALID_DATE_MESSAGE, Outlook2003AppointmentDialog.APP_TITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation );
							this.cboStartTime.Focus();
							this.cboStartTime.SelectAll();
							closeDialog = false;
						}

						//	Verify the end time
						try
						{
							DateTime tempEndTime = DateTime.Parse( this.cboEndTime.Text );
						}
						catch
						{
							MessageBox.Show( Outlook2003AppointmentDialog.INVALID_DATE_MESSAGE, Outlook2003AppointmentDialog.APP_TITLE, MessageBoxButtons.OK, MessageBoxIcon.Exclamation );
							this.cboEndTime.Focus();
							this.cboEndTime.SelectAll();
							closeDialog = false;
						}

					}

					this.SaveAppointment();

				}
				break;

				case "Delete":
				case "fileDelete":
				{
					if ( this.isExistingAppointment )
					{
						DialogResult result = MessageBox.Show( Outlook2003AppointmentDialog.DELETE_APPOINTMENT_CONFIRMATION, Outlook2003AppointmentDialog.APP_TITLE, MessageBoxButtons.YesNo, MessageBoxIcon.Exclamation );

						if ( result == DialogResult.Yes )
						{
							this.calendarInfo.Appointments.Remove( this.appointment );
							closeDialog = true;
						}
					}
				}
				break;

				case "fileClose":
				{
					closeDialog = true;
				}
				break;

				case "editCopy":
				{
					if ( activeControl != null )
						activeControl.Copy();
				}
				break;

				case "editCut":
				{
					if ( activeControl != null )
						activeControl.Cut();
				}
				break;

				case "editPaste":
				{
					if ( activeControl != null )
						activeControl.Paste();
				}
				break;

				case "editUndo":
				{
					if ( activeControl != null )
						activeControl.Undo();
				}
				break;

				case "editSelectAll":
				{
					if ( activeControl != null )
						activeControl.SelectAll();
				}
				break;

			}

			if ( closeDialog )
				this.Close();
		}


		private void chkAllDayEvent_CheckedChanged(object sender, System.EventArgs e)
		{
			//	Show/hide the start and end time comboboxes
			UltraCheckEditor checkEditor = sender as UltraCheckEditor;
			this.VerifyAppointmentStartAndEndTime();
			this.cboStartTime.Visible = ! checkEditor.Checked;
			this.cboEndTime.Visible = ! checkEditor.Checked;
		}

		private void chkReminder_CheckedChanged(object sender, System.EventArgs e)
		{
			//	Set the enabled state of the dependent controls
			UltraCheckEditor checkEditor = sender as UltraCheckEditor;
			bool enabled = checkEditor.Checked;
			this.cboReminder.Enabled = enabled;
			this.cmdReminder.Enabled = enabled;
		
		}

		private void cboStartTime_ValueChanged(object sender, System.EventArgs e)
		{		
			//	Update the end time when the start time changes, if we can
			try
			{
				DateTime tempStartTime = DateTime.Parse( this.cboStartTime.Text );
				DateTime tempStartDate = (DateTime)this.dtpStartTime.Value;
				DateTime temp = new DateTime( tempStartDate.Year, tempStartDate.Month, tempStartDate.Day, tempStartTime.Hour, tempStartTime.Minute, 0 );
				this.cboEndTime.Text = temp.AddMinutes( 30f ).ToShortTimeString();
			}
			catch{}
		}

		private void cmdReminder_Click(object sender, System.EventArgs e)
		{

			frmReminderSound frmSound = new frmReminderSound();
			
			//	Set the initial value, if there is one
			ExtendedAppointmentInfo info = this.appointment.Tag as ExtendedAppointmentInfo;
			if ( info != null )
			{
				if ( info.ReminderSound.Length > 0 )
					frmSound.SoundFile = info.ReminderSound;

				frmSound.PlaySound = info.PlayReminderSound;
			}

			frmSound.ShowDialog();
			if ( ! frmSound.Canceled )
			{
				info = this.appointment.Tag as ExtendedAppointmentInfo;
				if ( info == null )
					info = new ExtendedAppointmentInfo( this.appointment );

				if ( frmSound.SoundFile.Length > 0 )
					info.ReminderSound = frmSound.SoundFile;

				info.PlayReminderSound = frmSound.PlaySound;

				this.appointment.Tag = info;
			}
		}

		private void ultraTabControl1_SelectedTabChanged(object sender, Infragistics.Win.UltraWinTabControl.SelectedTabChangedEventArgs e)
		{
			if ( e.Tab.Key == "Scheduling" )
			{
				this.PopulateSchedulingListView();
			}
		}

		private void cboLocation_KeyDown(object sender, System.Windows.Forms.KeyEventArgs e)
		{
			//	If the Enter key is pressed, the dropdown is closed,
			//	and there is no item that matches the current text,
			//	add an item with the current text to the dropdown list.
			UltraComboEditor comboEditor = sender as UltraComboEditor;
			if ( e.KeyData == Keys.Enter && ! comboEditor.Editor.IsDroppedDown )
			{
				int index = comboEditor.FindString( comboEditor.Text );
				if ( index == -1 )
				{
					//	If we have hit the top on the number of items allowed
					//	in the location list, remove the oldest one.
					if ( comboEditor.Items.Count == Outlook2003AppointmentDialog.MAX_LOCATION_LIST_ITEMS )
						comboEditor.Items.RemoveAt(0);

					comboEditor.Items.Add( comboEditor.Text );
				}
			}
		}

		private void Outlook2003AppointmentDialog_Closing(object sender, System.ComponentModel.CancelEventArgs e)
		{
			if ( ! e.Cancel )
				this.SaveLocationsToRegistry();
		}

	}
	#endregion Outlook2003AppointmentDialog

	#region AppointmentExtendedInfo class
	/// <summary>
	/// Class that contains additional information about an Appointment.
	/// </summary>

    [Serializable()]
	public class ExtendedAppointmentInfo
	{
		#region Private members
		private Appointment appointment = null;
		private AppointmentLabel appointmentLabel = null;
		private string reminderSound = string.Empty;
		private bool playReminderSound = false;
        private string remarks = String.Empty;
		#endregion Private members

		#region Constructor
		/// <summary>
		/// 
		/// </summary>
		/// <param name="appointment">The Appointment object to which this <see cref="ExtendedAppointmentInfo"/> object is associated.</param>
		public ExtendedAppointmentInfo( Appointment appointment )
		{
			if ( appointment == null )
				throw new Exception( "Cannot associate an ExtendedAppointmentInfo object with a null Appointment." );

			this.appointment = appointment;
		}
		#endregion Constructor

		#region Properties

			#region AppointmentLabel
		/// <summary>
		/// Gets/sets the <see cref="AppointmentLabel"/> object associated with this <see cref="ExtendedAppointmentInfo"/> object.
		/// </summary>
		public AppointmentLabel Label
		{
			get{ return this.appointmentLabel; }
			set{ this.appointmentLabel = value; }
		}
			#endregion AppointmentLabel


        #region Remarks
        /// <summary>
        /// Gets/sets the <see cref="AppointmentLabel"/> object associated with this <see cref="ExtendedAppointmentInfo"/> object.
        /// </summary>
        public string Remarks
        {
            get { return this.remarks; }
            set { this.remarks = value; }
        }
        #endregion Remarks

			#region SoundFile
		/// <summary>
		/// Gets/sets the sound file that will be played when the reminder associated with this <see cref="ExtendedAppointmentInfo"/> object's appointment comes due.
		/// </summary>
		public string ReminderSound
		{
			get{ return this.reminderSound; }
			set{ this.reminderSound = value; }
		}
			#endregion SoundFile

		#region PlayReminderSound
		/// <summary>
		/// Gets/sets whether the <see cref="ReminderSound"/> will be played when the reminder associated with this <see cref="ExtendedAppointmentInfo"/> object's appointment comes due.
		/// </summary>
		public bool PlayReminderSound
		{
			get{ return this.playReminderSound; }
			set{ this.playReminderSound = value; }
		}
			#endregion PlayReminderSound


		#endregion Properties
	}
	#endregion AppointmentExtendedInfo class

	#region AppointmentLabel class
	/// <summary>
	/// Class that contains information about an Appointment's label
	/// </summary>

    [Serializable()]
	public class AppointmentLabel
	{
		#region Constants
		private static readonly int IMAGE_SIZE = 16;
		#endregion Constants

		#region Private members
		private string displayText = "None";
		private Color color = Color.Transparent;
		private Image image = null;
		#endregion Private members

		#region Constructor
		public AppointmentLabel( string	displayText, Color color )
		{
			this.displayText = displayText;
			this.color = color;
		}
		#endregion Constructor

		#region Properties

			#region DisplayText
		/// <summary>
		/// Gets the text that is displayed for this <see cref="AppointmentLabel"/>.
		/// </summary>
		public string DisplayText
		{
			get{ return this.displayText;}
		}
			#endregion DisplayText

			#region Color
		/// <summary>
		/// Gets the color that is displayed for this <see cref="AppointmentLabel"/>.
		/// </summary>
		public Color Color
		{
			get{ return this.color;}
		}
			#endregion Color

			#region Image
		/// <summary>
		/// Retuns an image that is a 16 X 16 representation of this <see cref="AppointmentLabel"/>'s <see cref="Color"/>.
		/// </summary>
		public Image Image
		{
			get
			{
				if ( this.image == null )
				{
					int imageSize = AppointmentLabel.IMAGE_SIZE;

					//	Create a new brush and a pen
					SolidBrush brush = new SolidBrush( this.Color );
					Pen pen = new Pen( SystemColors.WindowText );

					//	Create a new Bitmap, and fill it with the color
					//	specified by this instance's Color property.
					Bitmap image = new Bitmap( imageSize, imageSize );
					Graphics gr = Graphics.FromImage(image);
					gr.FillRectangle( brush, 0, 0, imageSize, imageSize );
					gr.DrawRectangle( pen, 0, 0, imageSize-1, imageSize-1 );

					//	Dispose of the GDI+ resources
					pen.Dispose();
					brush.Dispose();
					gr.Dispose();

					this.image = image;
				}

				return this.image;
			}
		}
			#endregion Image

		#endregion Properties

		#region Methods

			#region ToString
		/// <summary>
		/// Returns the value of the <see cref="DisplayText"/> property for this <see cref="AppointmentLabel"/>.
		/// </summary>
		/// <returns>Returns the string representation of this AppointmentLabel.</returns>
		public override string ToString()
		{
			return this.DisplayText;
		}
			#endregion ToString

		#endregion Methods

	}
	#endregion AppointmentLabel class

}
